#Tableau périodique

import matplotlib.pyplot as plt
import matplotlib.patches as mpatches
from matplotlib import colors as mcolors#pour la fonction to_rgba() : rectangles avec alpha différent de 1
import pandas as pd

#%%%%%%%%%%%%%%%%%%%%%%%%%%%
a=6#espace horizontal
b=6#espace vertical

blocs=False#afficher les limites des blocs
familles=False#afficher les limites des familles

#%%%%%%%%%%%%%%%%%%%%%%%%%%%

#extraction des données :
table=pd.read_csv("periodic-table.csv", 
delimiter=";", 
skiprows=2, #ne lit pas les deux premières lignes
#nrows=18,#permet de limiter à quelques périodes. Mais adapter les dimensions
usecols=[0, 1, 2, 3, 4], #sélectionne les colonnes utiles
names=['numéro atomique', "symbole", 'nom', 'ligne', 'colonne'], #renommer les colonnes
)
Z=table["numéro atomique"]
nom=table["nom"]
symb=table["symbole"]
ligne=table["ligne"]
colonne=table["colonne"]
#---------------------------------------------------------
plt.rcParams["font.family"] = "Ubuntu"#ou autre police installée

#paramètres du graphique
fig, ax=plt.subplots(figsize=(12,7), 
tight_layout=True, #marges réduites
)
#ax.set_aspect('equal')
plt.title("Le tableau périodique des éléments chimiques", fontsize=18)
plt.xticks([])
plt.yticks([])
#plt.axis('off')#retire le cadre du graphe
plt.xlim(0, 19*a)#à adapter aux dimensions choisies pour la figure
plt.ylim(-9*b, 0)# à adapter au nombre de périodes représentées

#tracé des cases :
for i in range(len(table)):
    if int(Z[i])<57 or int(Z[i])>71:#supprime les lanthanides
        if int(Z[i])<89 or int(Z[i])>103:#supprime les actinides
            plt.text(a*colonne[i], -b/2-b*ligne[i], symb[i], fontsize=13, va='bottom', ha='center')
            plt.text(a*colonne[i]-0.15*a, -b/2-b*(ligne[i]+0.1),int(Z[i]), fontsize=7, ha='right')
            plt.text(a*colonne[i], -b*(ligne[i]+0.15),nom[i], fontsize=6, ha='center')

#n° des colonnes :-------------------------------
for i in range(1, 19):
    plt.text(a*(i-0.2), -3, "%s"%(i), fontsize=8)
#------------------------------------------------------------------------------------

#Les FAMILLES :----------------------------------------
if familles==True:
    coul18=mcolors.to_rgba('orange', 0.5)#le dernier paramètre est alpha (opacité de 0 à 1)
    #ici : tracer un rectangle qui encadre les gaz nobles
    rectangle=mpatches.Rectangle((a*17.5, -b*8), a, b*7, fc=coul18, ec='k')
    ax.add_artist(rectangle)
    plt.text(a*4, -b*1.5, "gaz nobles", fontweight='bold', bbox=dict(facecolor=coul18))
    
    coul17=mcolors.to_rgba('gold', 0.5)
    #ici : tracer un rectangle qui encadre les halogènes
    rectangle=mpatches.Rectangle((a*16.5, -b*8), a, b*6, color=coul17, ec='k')
    ax.add_artist(rectangle)
    plt.text(a*4, -b*2.0, "halogènes", fontweight='bold', bbox=dict(facecolor=coul17))
    
    coul1=mcolors.to_rgba('royalblue', 0.5)
    #ici : tracer un rectangle qui encadre les alcalins
    rectangle=mpatches.Rectangle((0.5*a, -b*8), a, b*7, color=coul1, ec='k')
    ax.add_artist(rectangle)
    plt.text(a*4, -b*2.5, "alcalins", fontweight='bold', bbox=dict(facecolor=coul1))
    
    coul2=mcolors.to_rgba('yellowgreen', 0.5)
    #ici : tracer un rectangle qui encadre les alcalino-terreux
    rectangle=mpatches.Rectangle((1.5*a, -b*8), a, b*6, color=coul2, ec='k')
    ax.add_artist(rectangle)
    plt.text(a*4, -b*3.0, "alcalino-terreux", fontweight='bold', bbox=dict(facecolor=coul2))

#-----------------------------------------------------------------------------------------


#LES BLOCS---------------------------------------------
if blocs==True:
    coulS=mcolors.to_rgba('orange', 0.5)#BLOC s
    rectangle=mpatches.Rectangle((a/2, -b*8), a, b*7, color=coulS, ec='k')#alcalins
    ax.add_artist(rectangle)
    rectangle=mpatches.Rectangle((1.5*a, -b*8), a, b*6, color=coulS, ec='k')#col2
    ax.add_artist(rectangle)
    rectangle=mpatches.Rectangle((17.5*a, -b*2), a, b, color=coulS, ec='k')#He
    ax.add_artist(rectangle)
    plt.text(4*a, -b*1.75, "bloc s", fontweight='bold', bbox=dict(fc=coulS))
    
    coulP=mcolors.to_rgba('darkslateblue',0.5)#BLOC p
    rectangle=mpatches.Rectangle((12.5*a, -b*8), 6*a, b*6, color=coulP, ec='k')
    ax.add_artist(rectangle)
    plt.text(6.5*a, -b*1.75, "bloc p", fontweight='bold', bbox=dict(fc=coulP))
    
    coulD=mcolors.to_rgba('greenyellow',0.5)#BLOC d
    rectangle=mpatches.Rectangle((2.5*a, -b*8), 10*a, b*4, color=coulD, ec='k')
    ax.add_artist(rectangle)
    plt.text(9.5*a, -b*1.75, "bloc d", fontweight='bold', bbox=dict(fc=coulD))

#-----------------------------------------------------------------------------------------
if blocs==True:
    NomFichier='TableauPerBlocs'
elif familles==True:
    NomFichier='TableauPerFamilles'
else: NomFichier='TableauPerSimple'
fig.savefig(NomFichier)
fig.savefig(NomFichier+'.png', dpi=400)
fig.savefig(NomFichier+'.pdf')

#plt.show()
